@@ -32,16 +32,11 @@ using namespace Rcpp;
 using namespace boost;
 using namespace std;
 
-#define cc         *i
-#define NULLCHAR    (char)NULL
-#define pc          lastChar
-
-
 string soundex_single(string x, int maxCodeLen) {
   const string SOUNDEX = "01230120022455012623010202";
   string::iterator i;
   string code = "";
-  char lastCode = NULLCHAR;
+  char lastCode = (char)NULL;
 
   trim(x);
   to_upper(x);
@@ -78,7 +73,7 @@ string refinedSoundex_single(string x, int maxCodeLen) {
   const string SOUNDEX = "01360240043788015936020505";
   string::iterator i;
   string code = "";
-  char lastCode = NULLCHAR;
+  char lastCode = (char)NULL;
 
   trim(x);
   to_upper(x);
@@ -108,7 +103,6 @@ string refinedSoundex_single(string x, int maxCodeLen) {
   return code;
 }
 
-
 //' @rdname soundex
 //' @name soundex
 //' @title Soundex
@@ -129,6 +123,11 @@ string refinedSoundex_single(string x, int maxCodeLen) {
 //'
 //' @return soundex encoded character vector
 //'
+//' @section Caveats:
+//' The \code{soundex} and \code{refinedSoundex} algorithms are only
+//' defined for inputs over the standard English alphabet, \emph{i.e.},
+//' "A-Z." For inputs outside this range, the output is undefined.
+//'
 //' @references
 //' Charles P. Bourne and Donald F. Ford, "A study of methods for
 //' systematically abbreviating English words and names," \emph{Journal
@@ -162,7 +161,6 @@ CharacterVector soundex(CharacterVector word, int maxCodeLen = 4) {
     } else {
       res[i] = soundex_single(Rcpp::as<std::string>(word[i]), maxCodeLen);
     }
-
   }
 
   return res;
@@ -187,7 +185,6 @@ CharacterVector refinedSoundex(CharacterVector word, int maxCodeLen = 10) {
     } else {
       res[i] = refinedSoundex_single(Rcpp::as<std::string>(word[i]), maxCodeLen);
     }
-
   }
 
   return res;
